==================
nlg-deeppavlov-api
==================


.. image:: https://img.shields.io/pypi/v/ai_dialog_model.svg
        :target: https://pypi.python.org/pypi/ai_dialog_model

.. image:: https://img.shields.io/travis/simonmeoni/ai_dialog_model.svg
        :target: https://travis-ci.org/simonmeoni/ai_dialog_model

.. image:: https://readthedocs.org/projects/nlg-deeppavlov-api/badge/?version=latest
        :target: https://nlg-deeppavlov-api.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




set of NLG experimentation using deep pavlov library


* Free software: Apache Software License 2.0
* Documentation: https://nlg-deeppavlov-api.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
